@@ -13,6 +13,7 @@ Chromium
    <am>Latest Chromium browser and language pack</am>
    <ar>Latest Chromium browser and language pack</ar>
    <bg>Latest Chromium browser and language pack</bg>
+   <bn>Latest Chromium browser and language pack</bn>
    <ca>Darrer navegador Chromium i paquets de llengua</ca>
    <cs>Latest Chromium browser and language pack</cs>
    <da>Seneste Chromium-browser og -sprogpakke</da>
@@ -23,6 +24,7 @@ Chromium
    <et>Latest Chromium browser and language pack</et>
    <eu>Latest Chromium browser and language pack</eu>
    <fa>Latest Chromium browser and language pack</fa>
+   <fil_PH>Latest Chromium browser and language pack</fil_PH>
    <fi>Latest Chromium browser and language pack</fi>
    <fr>La dernière version de Chromium et son pack de langues</fr>
    <he_IL>Latest Chromium browser and language pack</he_IL>
@@ -38,20 +40,22 @@ Chromium
    <ko>Latest Chromium browser and language pack</ko>
    <lt>Latest Chromium browser and language pack</lt>
    <mk>Latest Chromium browser and language pack</mk>
+   <mr>Latest Chromium browser and language pack</mr>
    <nb>Latest Chromium browser and language pack</nb>
    <nl>Meest recente Chromium browser en talen pakket</nl>
    <pl>najnowsza przeglądarka Chromium i pakiet językowy</pl>
    <pt_BR>Navegador Chromium mais recente e respectivo pacote de idiomas</pt_BR>
-   <pt>Navegador Chromium mais recente e respectivo pacote de idiomas</pt>
+   <pt>Versão mais recente do navegador Chromium e respectivo pacote de idiomas</pt>
    <ro>Latest Chromium browser and language pack</ro>
    <ru>Браузер Chromium последней версии и языковые пакеты</ru>
-   <sk>Latest Chromium browser and language pack</sk>
+   <sk>Posledný Chromium prehliadač a jazykový balík</sk>
    <sl>Zadnja različica jezikovnega paketa za brskalnik Chromium</sl>
    <sq>Latest Chromium browser and language pack</sq>
    <sr>Latest Chromium browser and language pack</sr>
    <sv>Senaste Chromium webbläsare med språkpaket</sv>
-   <tr>Latest Chromium browser and language pack</tr>
+   <tr>En son Chromium tarayıcı ve dil paketi</tr>
    <uk>Крайня версія браузера Chromium з пакетом мов</uk>
+   <vi>Latest Chromium browser and language pack</vi>
    <zh_CN>Latest Chromium browser and language pack</zh_CN>
    <zh_TW>Latest Chromium browser and language pack</zh_TW>
 </description>
